==> abe-cli-0.2.7.tgz: package/src/server/app.js <==
import express from 'express'
import bodyParser from 'body-parser'
import exphbs from 'express-handlebars'
import controllers from './controllers'
import path from 'path'
import busboy from 'connect-busboy'
import portfinder from 'portfinder'
import clc from 'cli-color'
import openurl from 'openurl'

import {
  config,
  FileParser,
  fileUtils,
  printInput,
  openBlock,
  closeBlock,
  subBlock,
  testObj,
  math,
  notEmpty,
  printJson,
  className,
  isSubBlock,
  abe,
  compileAbe,
  moduloIf,
  attrAbe,
  folders,
  printConfig
} from '../cli'

var abePort = null

if(process.env.ROOT) config.set({root: process.env.ROOT})
if(process.env.PORT) abePort = process.env.PORT
config.set({webport: process.env.WEBPORT ? process.env.WEBPORT : 8081})

var html = exphbs.create({
  extname: '.' + config.files.templates.extension,
  helpers: {
    abe: compileAbe,
    math: math,
    printInput: printInput,
    moduloIf: moduloIf,
    testObj: testObj,
    closeBlock: closeBlock,
    subBlock: subBlock,
    openBlock: openBlock,
    isSubBlock: isSubBlock,
    notEmpty: notEmpty,
    printJson: printJson,
    className: className,
    attrAbe: attrAbe,
    folders: folders,
    printConfig: printConfig
  }
});

portfinder.getPort(function (err, freePort) {
  var app = express()
  var port = (abePort !== null) ? abePort : (freePort || 3000)

  app.set('views', path.join(__dirname, '/templates'))

  // app.set('template', )
  app.engine('.html', html.engine)
  app.set('view engine', '.html')

  app.locals.layout = false;

  app.use(express.static(__dirname + '/public'))
  FileParser.copySiteAssets()

  var sites = FileParser.getFolders(config.root.replace(/\/$/, ""), false, 0)
  let publish = fileUtils.concatPath(config.root, config.publish.url)
  app.use(express.static(publish))

  app.use(express.static(__dirname + '/node_modules/handlebars/dist'))
  app.use(busboy())
  app.use(bodyParser.json())
  app.use(bodyParser.urlencoded({extended: true}))
  app.use(controllers)

  app.listen(port, function() {
    console.log(clc.green(`\nserver running at http://localhost:${port}/`))
    if(process.env.OPENURL) openurl.open(`http://localhost:${port}/abe/`)
  })
})

==> abe-cli-0.2.18.tgz: package/src/server/app.js <==
import express from 'express'
import session from 'express-session'
import bodyParser from 'body-parser'
import exphbs from 'express-handlebars'
import controllers from './controllers'
import path from 'path'
import busboy from 'connect-busboy'
import portfinder from 'portfinder'
import clc from 'cli-color'
import openurl from 'openurl'

import {
  config,
  FileParser,
  fileUtils,
  printInput,
  abeImport,
  openBlock,
  closeBlock,
  subBlock,
  testObj,
  math,
  notEmpty,
  printJson,
  className,
  isSubBlock,
  abe,
  compileAbe,
  ifIn,
  moduloIf,
  attrAbe,
  folders,
  printConfig
} from '../cli'

var abePort = null

if(process.env.ROOT) config.set({root: process.env.ROOT.replace(/\/$/, '') + '/'})
if(process.env.PORT) abePort = process.env.PORT
config.set({webport: process.env.WEBPORT ? process.env.WEBPORT : 8081})

var html = exphbs.create({
  extname: '.' + config.files.templates.extension,
  helpers: {
    abe: compileAbe,
    math: math,
    printInput: printInput,
    abeImport: abeImport,
    moduloIf: moduloIf,
    testObj: testObj,
    closeBlock: closeBlock,
    subBlock: subBlock,
    openBlock: openBlock,
    isSubBlock: isSubBlock,
    notEmpty: notEmpty,
    printJson: printJson,
    className: className,
    attrAbe: attrAbe,
    folders: folders,
    printConfig: printConfig,
    ifIn: ifIn
  }
})

portfinder.getPort(function (err, freePort) {
  var app = express()
  var port = (abePort !== null) ? abePort : (freePort || 3000)

  app.set('views', path.join(__dirname, '/templates'))

  // app.set('template', )
  app.engine('.html', html.engine)
  app.set('view engine', '.html')

  app.locals.layout = false;

  app.use(express.static(__dirname + '/public'))
  FileParser.copySiteAssets()

  var sites = FileParser.getFolders(config.root.replace(/\/$/, ""), false, 0)
  let publish = fileUtils.concatPath(config.root, config.publish.url)
  app.use(express.static(publish))

  if(config.partials !== '') {
    if (fileUtils.isFile(fileUtils.concatPath(config.root, config.partials))) {
      app.use(express.static(fileUtils.concatPath(config.root, config.partials)))
    }
  }

  app.use(express.static(__dirname + '/node_modules/handlebars/dist'))
  app.use(busboy())
  app.use(bodyParser.json())
  app.use(bodyParser.urlencoded({extended: true}))
  app.use(session({secret: config.sessionSecret, resave: false, saveUninitialized: true}));
  app.use(controllers)

  app.listen(port, function() {
    console.log(clc.green(`\nserver running at http://localhost:${port}/`))
    if(process.env.OPENURL) openurl.open(`http://localhost:${port}/abe/`)
  })
})
